``pyramid_jqm``
===============

``pyramid_jqm`` is a package which provides "starter" scaffolding for
creating a `jQuery Mobile <http://jquerymobile.com>`_ Pyramid application.

See ``docs/index.rst`` in this distribution for detailed documentation.
